middleware
===========

Utilities for Python.

.. image:: https://img.shields.io/pypi/l/b3j0f.middleware.svg
   :target: https://pypi.python.org/pypi/b3j0f.middleware/
   :alt: License

.. image:: https://img.shields.io/pypi/status/b3j0f.middleware.svg
   :target: https://pypi.python.org/pypi/b3j0f.middleware/
   :alt: Development Status

.. image:: https://img.shields.io/pypi/v/b3j0f.middleware.svg
   :target: https://pypi.python.org/pypi/b3j0f.middleware/
   :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/b3j0f.middleware.svg
   :target: https://pypi.python.org/pypi/b3j0f.middleware/
   :alt: Supported Python versions

.. image:: https://img.shields.io/pypi/implementation/b3j0f.middleware.svg
   :target: https://pypi.python.org/pypi/b3j0f.middleware/
   :alt: Supported Python implementations

.. image:: https://img.shields.io/pypi/wheel/b3j0f.middleware.svg
   :target: https://travis-ci.org/b3j0f/middleware
   :alt: Download format

.. image:: https://travis-ci.org/b3j0f/middleware.svg?branch=master
   :target: https://travis-ci.org/b3j0f/middleware
   :alt: Build status

.. image:: https://coveralls.io/repos/b3j0f/middleware/badge.png
   :target: https://coveralls.io/r/b3j0f/middleware
   :alt: Code test coverage

.. image:: https://img.shields.io/pypi/dm/b3j0f.middleware.svg
   :target: https://pypi.python.org/pypi/b3j0f.middleware/
   :alt: Downloads

.. image:: https://readthedocs.org/projects/b3j0fmiddleware/badge/?version=master
   :target: https://readthedocs.org/projects/b3j0fmiddleware/?badge=master
   :alt: Documentation Status

.. image:: https://landscape.io/github/b3j0f/middleware/master/landscape.svg?style=flat
   :target: https://landscape.io/github/b3j0f/middleware/master
   :alt: Code Health

Links
=====

- `Homepage`_
- `PyPI`_
- `Documentation`_

Installation
============

pip install b3j0f.middleware

Features
========

This library provides tools and API for interacting with middleware systems such as Message Oriented Middleware, Database, Remote Procedure Call, etc.

Perspectives
============

- Cython implementation.

Donation
========

.. image:: https://cdn.rawgit.com/gratipay/gratipay-badge/2.3.0/dist/gratipay.png
   :target: https://gratipay.com/b3j0f/
   :alt: I'm grateful for gifts, but don't have a specific funding goal.

.. _Homepage: https://github.com/b3j0f/middleware
.. _Documentation: http://b3j0fmiddleware.readthedocs.org/en/master/
.. _PyPI: https://pypi.python.org/pypi/b3j0f.middleware/
